============
pydantic-aws
============


.. image:: https://img.shields.io/pypi/v/pydantic_aws.svg
        :target: https://pypi.python.org/pypi/pydantic_aws

.. image:: https://img.shields.io/travis/aaronlelevier/pydantic_aws.svg
        :target: https://travis-ci.com/aaronlelevier/pydantic_aws

.. image:: https://readthedocs.org/projects/pydantic-aws/badge/?version=latest
        :target: https://pydantic-aws.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/aaronlelevier/pydantic_aws/shield.svg
     :target: https://pyup.io/repos/github/aaronlelevier/pydantic_aws/
     :alt: Updates



Pydantic data validation for AWS models


* Free software: MIT license
* Documentation: https://pydantic-aws.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
